@@ -1,45 +1,49 @@
 """Sentry integration to Muffin framework."""
-import typing as t
 from contextvars import ContextVar
 from functools import partial
+from typing import Callable, Dict, List, Optional, TypeVar
 
-from asgi_tools.typing import Receive, Send, ASGIApp
-from muffin import ResponseError, ResponseRedirect, Application, Request
+from asgi_tools.types import TASGIApp, TASGIReceive, TASGISend
+from muffin import Application, Request, ResponseError, ResponseRedirect
 from muffin.plugins import BasePlugin
-from sentry_sdk import init as sentry_init, Hub, Scope as SentryScope
+from sentry_sdk import Hub
+from sentry_sdk import Scope as SentryScope
+from sentry_sdk import init as sentry_init
 from sentry_sdk.tracing import Transaction
 
-
 # Package information
 # ===================
 
-__version__ = "1.1.3"
+__version__ = "1.4.1"
 __project__ = "muffin-sentry"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
 
 
-TPROCESSOR = t.Callable[[t.Dict, t.Dict, Request], t.Dict]
-TVPROCESSOR = t.TypeVar('TVPROCESSOR', bound=TPROCESSOR)
+TProcess = Callable[[Dict, Dict, Request], Dict]
+TVProcess = TypeVar("TVProcess", bound=TProcess)
 
 
 class Plugin(BasePlugin):
 
     """Setup Sentry and send exceptions and messages."""
 
-    name = 'sentry'
+    name = "sentry"
     client = None
     defaults = {
-        'dsn': '',          # Sentry DSN
-        'sdk_options': {},  # See https://docs.sentry.io/platforms/python/configuration/options/
-        'ignore_errors': (ResponseError, ResponseRedirect),
+        "dsn": "",  # Sentry DSN
+        "sdk_options": {},  # See https://docs.sentry.io/platforms/python/configuration/options/
+        "ignore_errors": (ResponseError, ResponseRedirect),
     }
-    current_scope: ContextVar[t.Optional[SentryScope]] = ContextVar('sentry_scope', default=None)
+    current_scope: ContextVar[Optional[SentryScope]] = ContextVar(
+        "sentry_scope", default=None
+    )
+    processors: List[TProcess]
 
     def __init__(self, *args, **kwargs):
         """Initialize the plugin."""
         super(Plugin, self).__init__(*args, **kwargs)
-        self.processors: t.List[TPROCESSOR] = []
+        self.processors = []
 
     def setup(self, app: Application, **options):
         """Initialize Sentry Client."""
@@ -51,7 +55,13 @@ class Plugin(BasePlugin):
         # Setup Sentry
         sentry_init(dsn=self.cfg.dsn, **self.cfg.sdk_options)
 
-    async def middleware(self, handler: ASGIApp, request: Request, receive: Receive, send: Send):  # type: ignore
+    async def middleware(  # type: ignore
+        self,
+        handler: TASGIApp,
+        request: Request,
+        receive: TASGIReceive,
+        send: TASGISend,
+    ):
         """Capture exceptions to Sentry."""
         hub = Hub(Hub.current)
         with hub.configure_scope() as scope:
@@ -60,10 +70,12 @@ class Plugin(BasePlugin):
             self.current_scope.set(scope)
             scope.add_event_processor(partial(self.processData, request=request))
 
-            with hub.start_transaction(Transaction.continue_from_headers(
-                        request.headers, op=f"{request.scope['type']}.muffin"),
-                        custom_sampling_context={'asgi_scope': scope}
-                    ):
+            with hub.start_transaction(
+                Transaction.continue_from_headers(
+                    request.headers, op=f"{request.scope['type']}.muffin"
+                ),
+                custom_sampling_context={"asgi_scope": scope},
+            ):
                 try:
                     return await handler(request, receive, send)
 
@@ -72,23 +84,23 @@ class Plugin(BasePlugin):
                         hub.capture_exception(exc)
                     raise exc from None
 
-    def processor(self, fn: TVPROCESSOR) -> TVPROCESSOR:
+    def processor(self, fn: TVProcess) -> TVProcess:
         """Register a custom processor."""
         self.processors.append(fn)
         return fn
 
-    def processData(self, event: t.Dict, hint: t.Dict, request: Request) -> t.Dict:
+    def processData(self, event: Dict, hint: Dict, request: Request) -> Dict:
         """Prepare data before send it to Sentry."""
         if request:
             url = request.url
-            event['request'] = {
-                'url': f"{url.scheme}://{url.host}{url.path}",
-                'query_string': request.url.query_string,
-                'method': request.method,
-                'headers': dict(request.headers),
+            event["request"] = {
+                "url": f"{url.scheme}://{url.host}{url.path}",
+                "query_string": request.url.query_string,
+                "method": request.method,
+                "headers": dict(request.headers),
             }
 
-            if request.get('client'):
+            if request.get("client"):
                 event["request"]["env"] = {"REMOTE_ADDR": request.client[0]}
 
         for processor in self.processors:
